Contributing to pyozo
=====================

Any contribution to pyozo is welcome and appreciated.


Bug Reports and Feature Requests
--------------------------------

- Bug reports and feature requests should be made using [GitHub issues](https://github.com/zayfod/pyozo/issues).


Pull Requests
-------------

- All [tests](https://github.com/zayfod/pyozo/actions) should be passing on a PR, before it can be merged.
- Code should adhere to the [PEP 8 style guide](https://www.python.org/dev/peps/pep-0008/).
- Using docstrings is encouraged.
- Adding tests is encouraged.
